package com.flurry.android;

import java.util.List;
import java.util.Map;

/* loaded from: /storage/emulated/0/Documents/jadec/sources/com.UBI.A90.WW/dex-files/0.dex */
public class OfferHandler {
    public List<Map<String, String>> getOfferMapList() {
        return null;
    }

    public void onAdFilled(String str, Map<String, String> map) {
        be beVar = null;
        beVar.a(str, "filled", true, map);
    }

    public void onAdUnFilled(String str, Map<String, String> map) {
        be beVar = null;
        beVar.a(str, "unfilled", true, map);
    }

    public void onAdShown(String str, Map<String, String> map) {
        be beVar = null;
        beVar.a(str, "rendered", true, map);
    }

    public void onAdClicked(String str, Map<String, String> map) {
        be beVar = null;
        beVar.a(str, "clicked", true, map);
    }

    public void onAdClosed(String str, Map<String, String> map) {
        be beVar = null;
        beVar.a(str, "adClosed", true, map);
    }
}
